@@ -1,8 +1,6 @@
 from torm.builder.BaseBuilder import BaseBuilder
 from pymysql.cursors import DictCursor
 
-from torm.utl.Dict import Dict
-
 from torm.utl.Expression import expression as expr, Expression
 from combomethod import combomethod
 
@@ -136,9 +134,9 @@ class MysqlBuilder(BaseBuilder):
     # 改
     def update(self, data):
         if data and isinstance(data, dict):
-            #data = self._set_update_time(data)
             data = {key: value for key,
                     value in data.items() if key in self.__field__}
+
             return self.connection.execute(self._compile_update(data))
 
     @combomethod
@@ -158,7 +156,17 @@ class MysqlBuilder(BaseBuilder):
         except Exception as e:
             print(sql)
             raise e
-        return [Dict(index) for index in result]
+        return [Map(index) for index in result]
+
+    @combomethod
+    def all(self):
+        sql = self._compile_select()
+        try:
+            result = self.connection.execute(sql, DictCursor)
+        except Exception as e:
+            print(sql)
+            raise e
+        return [Map(index) for index in result]
 
     # 计数
     @combomethod
@@ -237,11 +245,6 @@ class MysqlBuilder(BaseBuilder):
     def _columnize(self, columns):
         return tuple(columns).__str__().replace('\'', '`')
 
-    @combomethod
-    def _valueize(self, data):
-        # return ','.join([tuple(index.values()).__str__() for index in data])
-        return ','.join([str(tuple(index.values())).replace("'NULL'", 'null') for index in data])
-
     @combomethod
     def _format_columns(self, columns):
         return [expr.format_column(column, self) for column in columns]
@@ -390,7 +393,7 @@ class MysqlBuilder(BaseBuilder):
     @combomethod
     def _compile_dict(self, data):
 
-        return ['{}={}'.format(expr.format_column(index, self), expr.format_string(value)) for index, value in data.items()]
+        return ['{}={}'.format(expr.format_column(index, self), expr.format_string(value)).replace("'NULL'", 'null').replace("None", 'null') for index, value in data.items()]
 
     @combomethod
     def _compile_tuple(self, data):
@@ -408,6 +411,11 @@ class MysqlBuilder(BaseBuilder):
     def _compile_delete(self):
         return 'delete from {}{}'.format(self.table_name, self._compile_where())
 
+    @combomethod
+    def _valueize(self, data):
+        # return ','.join([tuple(index.values()).__str__() for index in data])
+        return ','.join([str(tuple(index.values())).replace("'NULL'", 'null').replace("None", 'null') for index in data])
+
     @combomethod
     def InsertOne(self, item):
         self.reset()
@@ -451,14 +459,17 @@ class MysqlBuilder(BaseBuilder):
     @combomethod
     def UpdateOne(self, where={}, item={}):
         self.reset()
+
         if not where:
             return None
         if not item:
             return None
         where = Map(where, _depth=4)
 
-        if isinstance(item, self.__class__):
-            item = item.to_dict()
+        if not isinstance(item, self.__class__):
+            item = self(item)
+
+        item = item.to_dict()
 
         # 禁止更新id字段
         if "id" in item:
